@@ -20,11 +20,11 @@ from twisted.internet.protocol import ServerFactory
 from twisted.python.components import Componentized
 from twisted.python.log import ILogObserver
 # Attaching modules to the global state module simplifies import order hassles
-from carbon import util, state, events, instrumentation
+from carbon import state, util, events
 from carbon.log import carbonLogObserver
 from carbon.exceptions import CarbonConfigException
-state.events = events
-state.instrumentation = instrumentation
+
+state.events = state
 
 
 class CarbonRootService(MultiService):
@@ -38,6 +38,11 @@ class CarbonRootService(MultiService):
 
 def createBaseService(config):
     from carbon.conf import settings
+    from carbon import instrumentation
+
+    global state
+    state.instrumentation = instrumentation
+
     from carbon.protocols import (MetricLineReceiver, MetricPickleReceiver,
                                   MetricDatagramReceiver)
 
@@ -147,7 +152,7 @@ def createAggregatorService(config):
     root_service = createBaseService(config)
 
     # Configure application components
-    router = ConsistentHashingRouter()
+    router = ConsistentHashingRouter(settings.REPLICATION_FACTOR)
     client_manager = CarbonClientManager(router)
     client_manager.setServiceParent(root_service)
 
